@@ -1,4 +1,4 @@
-__version__ = '0.0.38'  # print(ultralytics.__version__)
+__version__ = '0.0.40'  # print(ultralytics.__version__)
 
 
 def checks(verbose=True):
@@ -7,13 +7,13 @@ def checks(verbose=True):
 
     import os
     import shutil
-    from IPython import display  # to display images and clear console output
     from .utils.general import emojis, check_requirements
     from .utils.torch_utils import select_device  # imports
 
     if verbose:
-        check_requirements(('psutil',))
+        check_requirements(('psutil', 'IPython'))
         import psutil
+        from IPython import display  # to display images and clear console output
 
         # System
         # gb = 1 / 1000 ** 3  # bytes to GB
